<?php 

/**
 * Here is all the custom colours for the theme.
 * $handle is a reference to the handle used with wp_enqueue_style()
 */

if (class_exists('WPLessPlugin')){
    $less = WPLessPlugin::getInstance();
    
    $body_font      = get_option('body_font', 'Open Sans');
    $heading_font   = get_option('heading_font', 'Open Sans');
    
    if( '' == get_option('body_font', 'Open Sans') ){
        $body_font = 'sans-serif';
    }
        
    if( '' == get_option('heading_font', 'Open Sans') ){
        $heading_font = 'sans-serif';
    }

    $less->setVariables(
        array(
            'color-primary'         => get_option('color-primary', '#e74c3c'),
            'color-secondary-1'     => get_option('color-secondary-1', '#2c3e50'),
            'color-secondary-2'     => get_option('color-secondary-2', '#3498db'),
            'color-bg-muted'        => get_option('color-bg-muted', '#f4f4f4'),
            'color-bg-primary'      => get_option('color-bg-primary', '#fff'),
            'color-text'            => get_option('color-text', '#777777'),
            'color-heading'         => get_option('color-heading', '#333333'),
            'color-borders'         => get_option('color-borders', '#dddddd'),
            'color-twitter'         => get_option('color-twitter', '#00a0d1'),
            'color-facebook'        => get_option('color-facebook', '#3b5998'),
            'color-tumblr'          => get_option('color-tumblr', '#34526f'),
            'color-pinterest'       => get_option('color-pinterest', '#910101'),
            'color-dribbble'        => get_option('color-dribbble', '#ea4c89'),
            'color-googleplus'      => get_option('color-googleplus', '#C63D2D'),
            'standard-space'        => get_option('theme_spacing', '80') . 'px',
            'standard-radius'       => get_option('theme_corners', '25') . 'px',
            'short-transition'      => get_option('short_transition','300') . 'ms',
            'medium-transition'     => get_option('medium_transition','500') . 'ms',
            'long-transition'       => get_option('long_transition','2000') . 'ms',
            'alt-font'              => get_option('alt_font', 'Raleway'),
            'color-link'            => get_option('color-link', '#333333'),
            'color-link-hover'      => get_option('color-link-hover', '#e74c3c'),
            'body-font'             => $body_font,
            'heading-font'          => $heading_font
        )
    );
    
}


if(!( function_exists('ebor_excerpt_more') )){
    function ebor_excerpt_more( $more ) {
        return '...';
    }
    add_filter('excerpt_more', 'ebor_excerpt_more');
}

if(!( function_exists('ebor_excerpt_length') )){
    function ebor_excerpt_length( $length ) {
        return 15;
    }
    add_filter( 'excerpt_length', 'ebor_excerpt_length', 999 );
}

/**
 * Filter the tag cloud appearance to match Tucson styling
 */
if(!( function_exists('ebor_tag_cloud') )){
    function ebor_tag_cloud($tag_string){
        $tag_string = preg_replace("/style='font-size:.+pt;'/", '', $tag_string);
        return $tag_string;
    }
    add_filter('wp_generate_tag_cloud', 'ebor_tag_cloud',10,3);
}

/**
 * Add body class so we know when we're using a page template from the page builder.
 */
if(!( function_exists('ebor_pivot_body_class') )){ 
    function ebor_pivot_body_class($c){
        global $post;
        if( isset($post->post_content) && has_shortcode( $post->post_content, 'vc_row' ) ) {
            $c[] = 'visual-composer-active';
        }
        return $c;
    }
    add_filter( 'body_class', 'ebor_pivot_body_class' );
}

/**
 * Add Search Link to Menu
 */
if(!( function_exists('ebor_one_page_nav_rewrite') )){ 
    function ebor_one_page_nav_rewrite($items, $args) {
        global $post;
        
        if(!( is_front_page() )){
            return str_replace('href="#', 'href="' . home_url() . '/#', $items);
        } else {
            return $items;
        }
    }
    if( get_option('site_version', 'multi-page') == 'one-page' )
        add_filter( 'wp_nav_menu_items', 'ebor_one_page_nav_rewrite', 20,2 );
}

/**
 * OCDI filters
 */
if( class_exists('OCDI_Plugin') ){
    
    function ebor_ocdi_plugin_intro_text( $default_text ) {
        $default_text .= '
            <div class="ocdi__intro-text">
                <h3>Read this before importing demo data!</h3>
                <p>We have prepared full written & video documentation to make your life with Pivot much more easy. It is worth spending a few minutes with this to familiarise yourself with the theme & its plugins before jumping in with your demo data, so <a href="https://tommusrhodus.ticksy.com/articles/" target="_blank">please read the theme documentation</a> before importing the demo data.</p>
                <hr />
            </div>
        ';
    
        return $default_text;
    }
    add_filter( 'pt-ocdi/plugin_intro_text', 'ebor_ocdi_plugin_intro_text' );
    
    function ebor_ocdi_confirmation_dialog_options ( $options ) {
        return array_merge( $options, array(
            'width'       => 600,
            'dialogClass' => 'wp-dialog',
            'resizable'   => false,
            'height'      => 'auto',
            'modal'       => true,
        ) );
    }
    add_filter( 'pt-ocdi/confirmation_dialog_options', 'ebor_ocdi_confirmation_dialog_options', 10, 1 );
    
    //Setup basic demo import
    function ebor_import_files() {
        
        $import_notice_vc = '
            <h3>Ready to Import Pivot Demo Data?</h3>
            <p>Please ensure all required plugins in "appearance => install plugins" are installed before running this demo importer.</p>
        ';
                
        return array(
            array(
                'import_file_name'             => 'Pivot Demo Data',
                'import_file_url'              => get_theme_file_uri( '/admin/demo-data/demo-data.xml' ),
                'import_widget_file_url'       => get_theme_file_uri( '/admin/demo-data/widgets.wie' ),
                'import_customizer_file_url'   => get_theme_file_uri( '/admin/demo-data/customizer.dat' ),
                'import_preview_image_url'     => get_theme_file_uri( '/screenshot.png' ),
                'import_notice'                => $import_notice_vc,
            ),
        );
        
    }
    add_filter( 'pt-ocdi/import_files', 'ebor_import_files' );
    
    //Setup front page and menus
    function ebor_after_import_setup() {
        
        // Assign menus to their locations.
        $main_menu = get_term_by( 'name', 'Main Menu', 'nav_menu' );
    
        set_theme_mod( 'nav_menu_locations', array(
                'primary'  => $main_menu->term_id,
            )
        );
    
        // Assign front page and posts page (blog page).
        $front_page_id = get_page_by_title( 'Home - Classic' );
        $blog_page_id  = get_page_by_title( 'Blog' );
    
        update_option( 'show_on_front', 'page' );
        update_option( 'page_on_front', $front_page_id->ID );
        update_option( 'page_for_posts', $blog_page_id->ID );
    
    }
    add_action( 'pt-ocdi/after_import', 'ebor_after_import_setup' );
    
    //Remove Branding
    add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );
    
    //Save customize options
    add_action( 'pt-ocdi/enable_wp_customize_save_hooks', '__return_true' );
    
    //Stop thumbnail generation
    add_filter( 'pt-ocdi/regenerate_thumbnails_in_content_import', '__return_false' );
    
}